searchNodes=[{"doc":"Elixir wrapper for the Pbkdf2 password hashing function.For a lower-level API, see Pbkdf2.Base.ConfigurationThe following parameter can be set in the config file:rounds - computational costthe number of rounds160_000 is the defaultIf you are hashing passwords in your tests, it can be useful to add the following to the config/test.exs file:config :pbkdf2_elixir, rounds: 1NB. do not use this value in production.Pbkdf2Pbkdf2 is a password-based key derivation function that uses a password, a variable-length salt and an iteration count and applies a pseudorandom function to these to produce a key.The original implementation used SHA-1 as the pseudorandom function, but this version uses HMAC-SHA-512, the default, or HMAC-SHA-256.WarningIt is recommended that you set a maximum length for the password when using Pbkdf2. This maximum length should not prevent valid users from setting long passwords. It is instead needed to combat denial-of-service attacks. As an example, Django sets the maximum length to 4096 bytes. For more information, see this link.","ref":"Pbkdf2.html","title":"Pbkdf2","type":"module"},{"doc":"Hashes a password, using hash_pwd_salt/2, and returns the password hash in a map.This is a convenience function that is especially useful when used with Ecto changesets.OptionsIn addition to the :hash_key option show below, this function also takes options that are then passed on to the hash_pwd_salt/2 function in this module.See the documentation for hash_pwd_salt/2 for further details.:hash_key - the password hash identifierthe default is :password_hashExample with EctoThe put_pass_hash function below is an example of how you can use add_hash to add the password hash to the Ecto changeset.defp put_pass_hash(%Ecto.Changeset{valid?: true, changes: %{password: password}} = changeset) do change(changeset, add_hash(password)) end defp put_pass_hash(changeset), do: changesetThis function will return a changeset with %{password_hash: password_hash} added to the changes map.","ref":"Pbkdf2.html#add_hash/2","title":"Pbkdf2.add_hash/2","type":"function"},{"doc":"Checks the password, using verify_pass/2, by comparing the hash with the password hash found in a user struct, or map.This is a convenience function that takes a user struct, or map, as input and seemlessly handles the cases where no user is found.Options:hash_key - the password hash identifierthis does not need to be set if the key is :password_hash or :encrypted_password:hide_user - run the no_user_verify/1 function if no user is foundthe default is trueExampleThe following is an example of using this function to verify a user's password:def verify_user(%{&quot;password&quot; =&gt; password} = params) do params |&gt; Accounts.get_by() |&gt; check_pass(password) endThe Accounts.get_by function in this example takes the user parameters (for example, email and password) as input and returns a user struct or nil.","ref":"Pbkdf2.html#check_pass/3","title":"Pbkdf2.check_pass/3","type":"function"},{"doc":"Generates a random salt.This function takes one optional argument - a keyword list (see below for options) or an integer with the salt length (in bytes).OptionsThe following options are available::salt_len - the length of the random saltthe default is 16 bytesfor more information, see the 'Salt length recommendations' section below:format - the length of the random saltthe default is :modular (modular crypt format)the other available options are :django and :hexExamplesHere is an example of generating a salt with the default salt length and format:Pbkdf2.gen_salt()To generate a different length salt:Pbkdf2.gen_salt(salt_len: 32)And to generate a salt in django output format:Pbkdf2.gen_salt(format: :django)Salt length recommendationsIn most cases, 16 bytes is a suitable length for the salt. It is not recommended to use a salt that is shorter than this (see below for details and references).According to the Pbkdf2 standard, the salt should be at least 8 bytes long, but according to NIST recommendations, the minimum salt length should be 16 bytes.","ref":"Pbkdf2.html#gen_salt/1","title":"Pbkdf2.gen_salt/1","type":"function"},{"doc":"Hashes a password with a randomly generated salt.OptionsIn addition to the options for gen_salt/1 (:salt_len and :format), this function also takes options that are then passed on to the hash_password function in the Pbkdf2.Base module.See the documentation for Pbkdf2.Base.hash_password/3 for further details.ExamplesThe following examples show how to hash a password with a randomly-generated salt and then verify a password:iex&gt; hash = Pbkdf2.hash_pwd_salt(&quot;password&quot;) ...&gt; Pbkdf2.verify_pass(&quot;password&quot;, hash) true iex&gt; hash = Pbkdf2.hash_pwd_salt(&quot;password&quot;) ...&gt; Pbkdf2.verify_pass(&quot;incorrect&quot;, hash) falseThe next examples show how to use some of the various available options:iex&gt; hash = Pbkdf2.hash_pwd_salt(&quot;password&quot;, rounds: 100_000) ...&gt; Pbkdf2.verify_pass(&quot;password&quot;, hash) true iex&gt; hash = Pbkdf2.hash_pwd_salt(&quot;password&quot;, digest: :sha256) ...&gt; Pbkdf2.verify_pass(&quot;password&quot;, hash) true iex&gt; hash = Pbkdf2.hash_pwd_salt(&quot;password&quot;, digest: :sha256, format: :django) ...&gt; Pbkdf2.verify_pass(&quot;password&quot;, hash) true","ref":"Pbkdf2.html#hash_pwd_salt/2","title":"Pbkdf2.hash_pwd_salt/2","type":"function"},{"doc":"Runs the password hash function, but always returns false.This function is intended to make it more difficult for any potential attacker to find valid usernames by using timing attacks. This function is only useful if it is used as part of a policy of hiding usernames.OptionsThis function should be called with the same options as those used by hash_pwd_salt/2.Hiding usernamesIn addition to keeping passwords secret, hiding the precise username can help make online attacks more difficult. An attacker would then have to guess a username / password combination, rather than just a password, to gain access.This does not mean that the username should be kept completely secret. Adding a short numerical suffix to a user's name, for example, would be sufficient to increase the attacker's work considerably.If you are implementing a policy of hiding usernames, it is important to make sure that the username is not revealed by any other part of your application.","ref":"Pbkdf2.html#no_user_verify/1","title":"Pbkdf2.no_user_verify/1","type":"function"},{"doc":"Verifies a password by hashing the password and comparing the hashed value with a stored hash.See the documentation for hash_pwd_salt/2 for examples of using this function.","ref":"Pbkdf2.html#verify_pass/2","title":"Pbkdf2.verify_pass/2","type":"function"},{"doc":"Base module for the Pbkdf2 password hashing library.","ref":"Pbkdf2.Base.html","title":"Pbkdf2.Base","type":"module"},{"doc":"","ref":"Pbkdf2.Base.html#django_salt/1","title":"Pbkdf2.Base.django_salt/1","type":"function"},{"doc":"Hash a password using Pbkdf2.OptionsThere are four options (rounds can be used to override the value in the config)::rounds - the number of roundsthe amount of computation, given in number of iterationsthe default is 160_000this can also be set in the config file:format - the output format of the hashthe default is :modular - modular crypt formatthe other available formats are::django - the format used in django applications:hex - the hash is encoded in hexadecimal:digest - the sha algorithm that pbkdf2 will usethe default is sha512:length - the length, in bytes, of the hashthe default is 64 for sha512 and 32 for sha256","ref":"Pbkdf2.Base.html#hash_password/3","title":"Pbkdf2.Base.hash_password/3","type":"function"},{"doc":"Verify a password by comparing it with the stored Pbkdf2 hash.","ref":"Pbkdf2.Base.html#verify_pass/6","title":"Pbkdf2.Base.verify_pass/6","type":"function"},{"doc":"Module that provides base64 encoding for pbkdf2.Most developers will not need to use this module directly.Pbkdf2 uses an adapted base64 alphabet (using . instead of + and with no padding).","ref":"Pbkdf2.Base64.html","title":"Pbkdf2.Base64","type":"module"},{"doc":"Decode using the adapted Pbkdf2 alphabet.Examplesiex&gt; Pbkdf2.Base64.decode(&quot;c3BhbWFuZGVnZ3M&quot;) &quot;spamandeggs&quot;","ref":"Pbkdf2.Base64.html#decode/1","title":"Pbkdf2.Base64.decode/1","type":"function"},{"doc":"Encode using the adapted Pbkdf2 alphabet.Examplesiex&gt; Pbkdf2.Base64.encode(&quot;spamandeggs&quot;) &quot;c3BhbWFuZGVnZ3M&quot;","ref":"Pbkdf2.Base64.html#encode/1","title":"Pbkdf2.Base64.encode/1","type":"function"},{"doc":"Module to provide statistics for the Pbkdf2 password hashing function.Configuring Pbkdf2The main configuration option for Pbkdf2 is the number of rounds that it uses. Increasing this value will increase the complexity, and time taken, of the Pbkdf2 function.Increasing the time that a password hash function takes makes it more difficult for an attacker to find the correct password. However, the amount of time a valid user has to wait also needs to be taken into consideration when setting the number of rounds.The correct number of rounds depends on circumstances specific to your use case, such as what level of security you want, how often the user has to log in, and the hardware you are using. However, for password hashing, we do not recommend setting the number of rounds to anything less than 100_000.","ref":"Pbkdf2.Stats.html","title":"Pbkdf2.Stats","type":"module"},{"doc":"Hash a password with Pbkdf2 and print out a report.This function hashes a password, and salt, with Pbkdf2.Base.hash_password/3 and prints out statistics which can help you choose how to configure Pbkdf2.OptionsIn addition to the options for Pbkdf2.Base.hash_password (rounds, output_fmt, digest and length), there are two options::password - the password usedthe default is &quot;password&quot;:salt - the salt usedthe default is &quot;somesaltSOMESALT&quot;","ref":"Pbkdf2.Stats.html#report/1","title":"Pbkdf2.Stats.report/1","type":"function"}]